@@ -148,7 +148,10 @@ struct MRIStepCouplingMem
 typedef _SUNDIALS_STRUCT_ MRIStepCouplingMem *MRIStepCoupling;
 
 /* Accessor routine to load built-in MRI table */
-SUNDIALS_EXPORT MRIStepCoupling MRIStepCoupling_LoadTable(ARKODE_MRITableID imethod);
+SUNDIALS_EXPORT MRIStepCoupling MRIStepCoupling_LoadTable(ARKODE_MRITableID method);
+
+/* Accessor routine to load built-in MRI table from string */
+SUNDIALS_EXPORT MRIStepCoupling MRIStepCoupling_LoadTableByName(const char *method);
 
 /* Utility routines to allocate/free/output coupling table structures */
 SUNDIALS_EXPORT MRIStepCoupling MRIStepCoupling_Alloc(int nmat, int stages,
@@ -371,6 +374,9 @@ SUNDIALS_EXPORT int MRIStepGetNumStepSolveFails(void *arkode_mem,
                                                 long int *nncfails);
 
 /* Linear solver optional output functions */
+SUNDIALS_EXPORT int MRIStepGetJac(void* arkode_mem, SUNMatrix* J);
+SUNDIALS_EXPORT int MRIStepGetJacTime(void* arkode_mem, sunrealtype* t_J);
+SUNDIALS_EXPORT int MRIStepGetJacNumSteps(void* arkode_mem, long* nst_J);
 SUNDIALS_EXPORT int MRIStepGetLinWorkSpace(void *arkode_mem,
                                            long int *lenrwLS,
                                            long int *leniwLS);
